@@ -1499,14 +1499,16 @@ bad:
 
 extern char *perl_params;
 
+static clock_t lastreal,tickspersec;
+
 static int
 dotime(char *cmd)
 {
-    static clock_t lastreal;
+    /* static clock_t lastreal; */
     clock_t now;
     static struct tms lastbuf;
     struct tms tbuf;
-    static clock_t tickspersec;
+    /* static clock_t tickspersec; */
     /* extern char *perl_params; */
 
     if (tickspersec == 0)
@@ -1518,11 +1520,34 @@ dotime(char *cmd)
            ((double)(tbuf.tms_utime - lastbuf.tms_utime)) / tickspersec,
            ((double)(tbuf.tms_stime - lastbuf.tms_stime)) / tickspersec,
            perl_params);
-    lastreal = now;
+    lastreal = times(&tbuf);
     lastbuf = tbuf;
     return 0;
 }
 
+
+#define	reference 46276.0 /* Konstante aus 11569 sec * 4 MHz (Referenz) */
+
+double t, mhz;
+
+void timexprint()
+{
+	struct tms tbuf;
+
+	if (tickspersec == 0)
+	    tickspersec = sysconf(_SC_CLK_TCK);
+	t = ((double)(times(&tbuf) - lastreal)) / tickspersec; /* time */ 
+	if (t == 0.0) {
+	    printf("Time ist 0.0 second!\n");
+	} else {
+	    mhz = reference / t;
+	    printf("\nTime of zexall is %.3f seconds!\r\n",t);
+	    printf("That is like a Z80 with %.3f MHz (%.3f GHz).\r\n",
+			mhz,mhz/1000.0);
+	}
+}
+
+
 static int
 dogo(char *cmd)
 {
