@@ -90,6 +90,8 @@ extern bool rtc_avail; /* nur zum Testen */
 static void
 usage(void)
 {
+    char c;
+
     fprintf(stderr,
             "Usage: %s {flags} {commands}\n"
             "   -b <file>       boot from this file\n"
@@ -107,7 +109,50 @@ usage(void)
             "   -z <xxxx>       (hex) address of z3env (if desired)\n"
             "   -1              all drives uses 128 byte sectors (under CP/M 3.1)\n"
             "                   (normal 2048 byte sectors are used, 128 byte\n"
-            "                   sectors are necessary to use a disk editor)\n\n");
+            "                   sectors are necessary to use a disk editor)\n\n"
+	    "Press RETURN to continue ...");
+    read(fileno(stdin), &c, 1);
+    fprintf(stderr,
+	    "\n"
+	    "Features: MMU:     Memory Management Unit with 16 tables and 16 page pointers\n"
+	    "   of   :          per table. This is the basis for running CP/M 3.1. A bank\n"
+	    "YAZE-AG :          switch is simple done with a pointer to one of the 16 tables\n"
+	    "                   and is very fast.\n\n"
+	    "          KeyTr:   Key translation: Allows to use the cursor keys of the PC in\n"
+	    "                   Wordstar and on the command line of CP/M 3.1. Commands can\n"
+	    "                   be put on function keys and many more. This software module\n"
+	    "                   is Copyright (c) by John Saxton (see yaze-keys.pdf).\n\n"
+	    "          WinSz:   Window size handler/routine: This handler initializes the\n"
+	    "                   lines and columns in the SCB of CP/M 3.1 like the lines and\n"
+	    "                   columns of the used terminal emulator. The CP/M 3.1 system\n"
+	    "                   utilities (like TYPE, DIR, ...) and the patched Wordstar\n"
+	    "                   4.00 (A:WS.COM) uses this two variables to setup the screen.\n\n"
+	    "          MHz:     You can define a clock rate in the monitor of yaze-ag.\n"
+	    "                   This allows to run the emulator at the defined clockrate\n"
+	    "                   like e.g. \"4000\" for 4000 kHz (4.0 MHz) or any other clock\n"
+	    "                   rate. Clock rate \"0\" returns to max speed.\n\n"
+	    "Press RETURN to continue ...");
+    read(fileno(stdin), &c, 1);
+    fprintf(stderr,
+	    "\n"
+	    "          ZSM4:    ZSM4 is a free Macro Assembler for the Z80/Z180/Z280. The\n"
+	    "                   Assembler is created by Hector Peraza. The project page is\n"
+	    "                   on \"https://github.com/hperaza/ZSM4\". The licence is the\n"
+	    "                   GPLv2 (General Public Licence Version 2). The source files\n"
+	    "                   of this Assembler can be mounted on drive O:.\n"
+	    "                   This Assembler is now the standard for assemble BOOTSYS and\n"
+	    "                   the BIOS3-Z80-files for YAZE-AG (see drive P:).\n\n"
+	    "Copyright (c) 1995,1998 by Frank D.Cringle (until yaze-1.10, CP/M 2.2).\n\n"
+	    "Keytranslation is Copyright (c) 2000,2015 by Jon Saxton (Australia).\n\n"
+	    "The basis for the MMU was the idea of the Pagetables by Michael Haardt.\n\n"
+	    "MMU, CP/M 3.1 and other extensions Copyright (c) 2000,2022 by Andreas Gerlich.\n"
+	    "(See the file yaze-ag_doc.html in the documentation about the news features of\n"
+	    " yaze-ag-2.xx.x since yaze-1.10.)\n\n"
+	    "The License of this Open Source Project is the GNU GENERAL PUBLIC LICENSE\n"
+	    "Version 2, June 1991 (GPLv2).\n\n"
+	
+	    "Press RETURN to continue ...");
+    read(fileno(stdin), &c, 1);
 #endif
 
     exit (1);
@@ -252,6 +297,7 @@ extern int getopt(int argc, char * const argv[],
 extern char *optarg;
 extern int optind, opterr, optopt;
 
+/* Core Z80Core = simz80;	\* funktion pointer default simz80() */
 
 int
 main(int argc, char **argv)
@@ -274,9 +320,9 @@ main(int argc, char **argv)
     puts("\nYet Another Z80 Emulator by AG, "
 	"\033[32m"
 
-	"final release " VERSION
+	"final release " VERSION 
 /*	"development v" VERSION "-" DEVVER "_beta" */
-/*	"release candidate " VERSION "-" DEVVER    */
+/*	"release candidate " VERSION "-" DEVVER */
 
 	"\033[0m"
 
@@ -294,16 +340,10 @@ main(int argc, char **argv)
 */
 	/* " (devel version)" */
 #ifdef MMU
-	" (MMU,KeyTr,WinSz,MHz)"
+	"\r\nFeatures: MMU,KeyTr,WinSz,MHz,ZSM4, Copyright (use the flag \"-?\" for details)."
 #endif
-	"\r\n"
-	"Copyright 1995,1998 Frank D. Cringle. "
-	"Pagetables Copyright by Michael Haardt.\r\n"
-	"MMU and CP/M 3.1 extensions "
-	"Copyright (c) 2000,2019 by Andreas Gerlich.\r\n"
-	"Keytranslation Copyright (c) 2010,2015 by Jon Saxton\r\n"
-	"yaze-ag comes with ABSOLUTELY NO WARRANTY; for details\r\n"
-	"see the file \"COPYING\" in the distribution directory.\r\n");
+	"\r\nYAZE-AG comes with ABSOLUTELY NO WARRANTY; for details "
+	"see the file \"COPYING\".\r\n");
 
     while ((c = getopt(argc, argv, "b:l:s:h:w:"
 #ifdef BIOS
