@@ -1500,6 +1500,10 @@ wboot:
         HL = '/';   /* slash in UNIX and also in Windows (with Cygwin) */
         break;
 
+    case 0xA2:			/* timexprint funktion is in monitor.c */
+	timexprint();
+	break;
+
     case 0xA8:		/* Report/load keyboard translation */
 	HL = 0;
         getCPMCommandLine();
