@@ -8,6 +8,8 @@
 #define NANOS_PER_MILLI     1000000
 #define MILLIS_PER_SEC      1000
 
+extern int nanosleep(const struct timespec *req, struct timespec *rem);
+
 const bool rtc_avail = true;
 
 ui32 sim_os_msec (void)
@@ -28,6 +30,6 @@ struct timespec treq;
 
 treq.tv_sec = milliseconds / MILLIS_PER_SEC;
 treq.tv_nsec = (milliseconds % MILLIS_PER_SEC) * NANOS_PER_MILLI;
-(void) nanosleep (&treq, NULL);
+nanosleep (&treq, NULL);
 return sim_os_msec () - stime;
 }
